FluidSim Core
=============

Pure-Python core library for FluidSim_ framework. This package provides
generic base classes and utilities to build new solvers.

**Documentation**: https://fluidsim.readthedocs.io/en/latest/generated/fluidsim_core.html

.. _FluidSim: https://fluidsim.readthedocs.io
